django-realestate
=================

.. image:: https://secure.travis-ci.org/wm3ndez/realestate.png?branch=master
   :target: http://travis-ci.org/wm3ndez/realestate
.. image:: https://pypip.in/v/django-realestate/badge.png
   :target: https://crate.io/packages/django-realestate
.. image:: https://pypip.in/d/django-realestate/badge.png
   :target: https://crate.io/packages/django-realestate

Documentation
=============

Documentation available at http://django-real-estate.readthedocs.org/